/*
 *  Copyright (C) 2001 Philip Langdale
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __ContentOverrideHandler_h
#define __ContentOverrideHandler_h

#include "nsError.h"
#include "nsCURILoader.h"

//
// GContentOverrideHandler
// 
#define G_CONTENTOVERRIDEHANDLER_CID \
   {0x091140b8, 0x6266, 0x438a, {0x8c, 0xf0, 0x4b, 0xd7, 0xb9, 0xe, 0x05, 0xd5}}

class nsIFactory;

extern nsresult NS_NewContentOverrideHandlerFactory(nsIFactory** aFactory);

#endif
